@@ -1777,6 +1777,7 @@ static void GenerateCalEntries(int col)
             case T_ErrMsg:  r=DoErrMsg(&p);  break;
             case T_Rem:     r=DoCalRem(&p, col); break;
             case T_If:      r=DoIf(&p);      break;
+            case T_Return:  r=DoReturn(&p);  break;
             case T_IfTrig:  r=DoIfTrig(&p);  break;
             case T_Else:    r=DoElse(&p);    break;
             case T_EndIf:   r=DoEndif(&p);   break;
@@ -2018,7 +2019,7 @@ static int DoCalRem(ParsePtr p, int col)
         }
     } else {
         /* Calculate the trigger date */
-        dse = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
+        dse = ComputeTrigger(get_scanfrom(&trig), &trig, &tim, &r, 1);
         if (r) {
             if (r == E_CANT_TRIG && trig.maybe_uncomputable) {
                 r = OK;
@@ -2049,6 +2050,13 @@ static int DoCalRem(ParsePtr p, int col)
         return OK;
     }
 
+    /* Filter unwanted events/todos */
+    if ((TodoFilter == ONLY_TODOS && !trig.is_todo) ||
+        (TodoFilter == ONLY_EVENTS && trig.is_todo)) {
+        FreeTrig(&trig);
+        return OK;
+    }
+
     /* Save nonconst_expr flag */
     nonconst_expr = p->nonconst_expr;
     /* Convert PS and PSF to PASSTHRU */
@@ -2148,14 +2156,18 @@ static int DoCalRem(ParsePtr p, int col)
             }
             (void) sscanf(DBufValue(&pre_buf), "%d %d %d",
                           &col_r, &col_g, &col_b);
-            if (col_r < 0) col_r = 0;
-            else if (col_r > 255) col_r = 255;
-            if (col_g < 0) col_g = 0;
-            else if (col_g > 255) col_g = 255;
-            if (col_b < 0) col_b = 0;
-            else if (col_b > 255) col_b = 255;
-            if (!PsCal && !DoSimpleCalendar) {
+            if (col_r < 0 || col_g < 0 || col_b < 0 ||
+                col_r > 255 || col_g > 255 || col_b > 255) {
+                is_color = 0;
+                col_r = -1;
+                col_g = -1;
+                col_b = -1;
+                trig.passthru[0] = 0;
                 DBufFree(&pre_buf);
+            } else {
+                if (!PsCal && !DoSimpleCalendar) {
+                    DBufFree(&pre_buf);
+                }
             }
         }
     }
@@ -2426,7 +2438,7 @@ WriteJSONInfoChain(TrigInfo *ti)
     }
     printf("},");
 }
-void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
+void WriteJSONTrigger(Trigger const *t, int include_tags)
 {
     /* wd is an array of days from 0=monday to 6=sunday.
        We convert to array of strings */
@@ -2454,6 +2466,8 @@ void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
     if (t->y != NO_YR) {
         PrintJSONKeyPairInt("y", t->y);
     }
+    PrintJSONKeyPairInt("is_todo", t->is_todo);
+    PrintJSONKeyPairDate("complete_through", t->complete_through);
     if (t->back) {
         PrintJSONKeyPairInt("back", t->back);
     }
@@ -2499,8 +2513,15 @@ void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
     if (t->once != NO_ONCE) {
         PrintJSONKeyPairInt("once", t->once);
     }
-    if (t->scanfrom != today) {
-        PrintJSONKeyPairDate("scanfrom", t->scanfrom);
+    if (t->scanfrom != NO_SCANFROM) {
+        if (t->scanfrom >= 0) {
+            PrintJSONKeyPairDate("scanfrom", t->scanfrom);
+        } else {
+            PrintJSONKeyPairInt("scanfrom", t->scanfrom);
+        }
+    }
+    if (t->max_overdue >= 0) {
+        PrintJSONKeyPairInt("max_overdue", t->max_overdue);
     }
     PrintJSONKeyPairDate("from", t->from);
     PrintJSONKeyPairInt("priority", t->priority);
@@ -2528,7 +2549,7 @@ void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
     }
 }
 
-static void WriteSimpleEntryProtocol2(CalEntry *e, int today)
+static void WriteSimpleEntryProtocol2(CalEntry *e)
 {
     char const *s;
     if (DoPrefixLineNo) {
@@ -2555,7 +2576,7 @@ static void WriteSimpleEntryProtocol2(CalEntry *e, int today)
             PrintJSONKeyPairInt("trep", e->tt.rep);
         }
     }
-    WriteJSONTrigger(&e->trig, 0, today);
+    WriteJSONTrigger(&e->trig, 0);
     if (e->nonconst_expr) {
         PrintJSONKeyPairInt("nonconst_expr", e->nonconst_expr);
     }
@@ -2660,7 +2681,7 @@ static void WriteSimpleEntries(int col, int dse)
             }
             DidADay = 1;
             printf("{\"date\":\"%04d-%02d-%02d\",", y, m+1, d);
-            WriteSimpleEntryProtocol2(e, dse);
+            WriteSimpleEntryProtocol2(e);
             printf("}");
             if (PsCal != PSCAL_LEVEL3) {
                 printf("\n");
@@ -2893,7 +2914,8 @@ char const *SimpleTime(int tim)
             if (h == 0) hh=12;
             else if (h > 12) hh=h-12;
             else hh=h;
-            snprintf(buf, sizeof(buf), "%d%c%02d%.64s ", hh, TimeSep, min, (h>=12) ? tr("pm") : tr("am"));
+            snprintf(buf, sizeof(buf), "%d%c%02d%.64s ", hh, TimeSep, min, (h>=12) ? tr("pm") :
+                                                                                     tr("am"));
         }
         break;
 
