@@ -41,6 +41,13 @@
 #include "globals.h"
 #include "err.h"
 
+#ifdef USE_READLINE
+#include <readline/readline.h>
+#endif
+#ifdef USE_READLINE_HISTORY
+#include <readline/history.h>
+#endif
+
 
 /* Convenient macros for closing files */
 #define FCLOSE(fp) ((((fp)!=stdin)) ? (fclose(fp),(fp)=NULL) : ((fp)=NULL))
@@ -134,6 +141,9 @@ void InitFiles(void)
         fprintf(ErrFp, "Unable to initialize filename hash table: Out of memory.  Exiting.\n");
         exit(1);
     }
+#ifdef USE_READLINE_HISTORY
+    using_history();
+#endif
 }
 
 void SetCurrentFilename(char const *fname)
@@ -179,17 +189,14 @@ got_a_fresh_line(void)
     WarnedAboutImplicit = 0;
 }
 
-static void set_cloexec(FILE *fp)
+void set_cloexec(int fd)
 {
     int flags;
-    int fd;
-    if (fp) {
-        fd = fileno(fp);
-        flags = fcntl(fd, F_GETFD);
-        if (flags >= 0) {
-            flags |= FD_CLOEXEC;
-            fcntl(fd, F_SETFD, flags);
-        }
+
+    flags = fcntl(fd, F_GETFD);
+    if (flags >= 0) {
+        flags |= FD_CLOEXEC;
+        fcntl(fd, F_SETFD, flags);
     }
 }
 
@@ -218,7 +225,7 @@ static void OpenPurgeFile(char const *fname, char const *mode)
         fprintf(ErrFp, tr("Cannot open `%s' for writing: %s"), DBufValue(&fname_buf), strerror(errno));
         fprintf(ErrFp, "\n");
     }
-    set_cloexec(PurgeFP);
+    set_cloexec(fileno(PurgeFP));
     DBufFree(&fname_buf);
 }
 
@@ -283,6 +290,11 @@ static int ReadLineFromFile(int use_pclose)
     int l;
     char copy_buffer[4096];
     size_t n;
+    int force_eof = 0;
+
+#ifdef USE_READLINE
+    int read_some = 0;
+#endif
 
     DynamicBuffer buf;
 
@@ -291,17 +303,51 @@ static int ReadLineFromFile(int use_pclose)
 
     LineNoStart = LineNo+1;
     while(fp) {
+#ifdef USE_READLINE
+        if (fileno(fp) == STDIN_FILENO && isatty(STDIN_FILENO) && isatty(STDOUT_FILENO)) {
+            char *lin;
+            if (should_ignore_line()) {
+                if (read_some) {
+                    lin = readline("Rem...? ");
+                } else {
+                    lin = readline("Remind? ");
+                }
+            } else {
+                if (read_some) {
+                    lin = readline("Rem...> ");
+                } else {
+                    lin = readline("Remind> ");
+                }
+            }
+            if (lin) {
+                read_some = 1;
+                DBufFree(&buf);
+                if (DBufPuts(&buf, lin) != OK) {
+                    free(lin);
+                    DBufFree(&buf);
+                    return E_NO_MEM;
+                }
+                free(lin);
+                force_eof = 0;
+            } else {
+                force_eof = 1;
+            }
+        } else {
+#endif
         if (DBufGets(&buf, fp) != OK) {
             DBufFree(&LineBuffer);
             return E_NO_MEM;
         }
+#ifdef USE_READLINE
+        }
+#endif
         LineNo++;
         if (ferror(fp)) {
             DBufFree(&buf);
             DBufFree(&LineBuffer);
             return E_IO_ERR;
         }
-        if (feof(fp)) {
+        if (feof(fp) || force_eof) {
             if (use_pclose) {
                 PCLOSE(fp);
             } else {
@@ -363,6 +409,9 @@ static int ReadLineFromFile(int use_pclose)
             CurLine = DBufValue(&LineBuffer);
         }
 
+#ifdef USE_READLINE_HISTORY
+        add_history(CurLine);
+#endif
         got_a_fresh_line();
         clear_callstack();
         if (DebugFlag & DB_ECHO_LINE) OutputLine(ErrFp);
@@ -427,7 +476,9 @@ static int OpenFile(char const *fname)
         }
     } else {
         fp = fopen(fname, "r");
-        set_cloexec(fp);
+        if (fp) {
+            set_cloexec(fileno(fp));
+        }
         if (DebugFlag & DB_TRACE_FILES) {
             fprintf(ErrFp, tr("Reading `%s': Opening file on disk"), fname);
             fprintf(ErrFp, "\n");
@@ -449,7 +500,7 @@ static int OpenFile(char const *fname)
             if (strcmp(fname, "-")) {
                 fp = fopen(fname, "r");
                 if (!fp || !CheckSafety()) return E_CANT_OPEN;
-                set_cloexec(fp);
+                set_cloexec(fileno(fp));
                 if (PurgeMode) OpenPurgeFile(fname, "w");
             } else {
                 fp = stdin;
@@ -650,7 +701,7 @@ static int PopFile(void)
         if (strcmp(i->filename, "-")) {
             fp = fopen(i->filename, "r");
             if (!fp || !CheckSafety()) return E_CANT_OPEN;
-            set_cloexec(fp);
+            set_cloexec(fileno(fp));
             if (PurgeMode) OpenPurgeFile(i->filename, "a");
         } else {
             fp = stdin;
