@@ -798,6 +798,15 @@ void InitRemind(int argc, char const *argv[])
 
     }
 
+    /* JSON mode turns off sorting */
+    if (JSONMode) {
+        SortByTime = SORT_NONE;
+        SortByDate = SORT_NONE;
+        SortByPrio = SORT_NONE;
+        /* Make sure we don't blat errors to stdout! */
+        ErrFp = stderr;
+    }
+
     /* Figure out the offset from UTC */
     if (CalculateUTC) {
         (void) CalcMinsFromUTC(DSEToday, MinutesPastMidnight(0),
@@ -848,6 +857,16 @@ void Usage(void)
     fprintf(ErrFp, " -m     Start calendar with Monday rather than Sunday\n");
     fprintf(ErrFp, " -y     Synthesize tags for tagless reminders\n");
     fprintf(ErrFp, " -j[n]  Run in 'purge' mode.  [n = INCLUDE depth]\n");
+    fprintf(ErrFp, "\nLong Options:\n");
+    fprintf(ErrFp, " --version                Print Remind version\n");
+    fprintf(ErrFp, " --hide-completed-todos   Don't show completed todos on calendar\n");
+    fprintf(ErrFp, " --only-todos             Only issue TODO reminders\n");
+    fprintf(ErrFp, " --only-events            Do not issue TODO reminders\n");
+    fprintf(ErrFp, " --json                   Use JSON output instead of plain-text\n");
+    fprintf(ErrFp, " --max-execution-time=n   Limit execution time to n seconds\n");
+    fprintf(ErrFp, " --print-config-cmd       Print ./configure cmd used to build Remind\n");
+    fprintf(ErrFp, " --print-errs             Print all possible error messages\n");
+    fprintf(ErrFp, " --print-tokens           Print all possible Remind tokens\n");
     fprintf(ErrFp, "\nRemind home page: %s\n", PACKAGE_URL);
     exit(EXIT_FAILURE);
 }
@@ -1131,6 +1150,33 @@ ProcessLongOption(char const *arg)
 
         return;
     }
+    if (!strcmp(arg, "only-todos")) {
+        if (TodoFilter == ONLY_EVENTS) {
+            fprintf(ErrFp, "remind: Cannot combine --only-todos and --only-events\n");
+            exit(1);
+        }
+        TodoFilter = ONLY_TODOS;
+        return;
+    }
+    if (!strcmp(arg, "only-events")) {
+        if (TodoFilter == ONLY_TODOS) {
+            fprintf(ErrFp, "remind: Cannot combine --only-todos and --only-events\n");
+            exit(1);
+        }
+        TodoFilter = ONLY_EVENTS;
+        return;
+    }
+    if (!strcmp(arg, "flush")) {
+        setvbuf(stdout, NULL, _IONBF, 0);
+        setvbuf(stderr, NULL, _IONBF, 0);
+        return;
+    }
+    if (!strcmp(arg, "json")) {
+        JSONMode = 1;
+        DontQueue = 1;
+        return;
+    }
+
     if (!strcmp(arg, "version")) {
         printf("%s\n", VERSION);
         exit(EXIT_SUCCESS);
@@ -1149,6 +1195,11 @@ ProcessLongOption(char const *arg)
         exit(EXIT_SUCCESS);
     }
 
+    if (!strcmp(arg, "hide-completed-todos")) {
+        HideCompletedTodos = 1;
+        return;
+    }
+
     if (!strcmp(arg, "print-tokens")) {
         print_remind_tokens();
         print_builtinfunc_tokens();
