@@ -172,6 +172,9 @@ int main(int argc, char *argv[])
     ShouldCache = (Iterations > 1);
 
     while (Iterations--) {
+        if (JSONMode) {
+            printf("[\n");
+        }
         PerIterationInit();
         DoReminders();
 
@@ -194,7 +197,35 @@ int main(int argc, char *argv[])
                 Eprint("%s", GetErr(E_PUSHF_NO_POP));
             }
             if (!Daemon && !NextMode && !NumTriggered && !NumQueued) {
-                printf("%s\n", GetErr(E_NOREMINDERS));
+                if (!JSONMode) {
+                    printf("%s\n", GetErr(E_NOREMINDERS));
+                } else {
+                    if (!DidMsgReminder) {
+                        DynamicBuffer buf;
+                        DBufInit(&buf);
+                        /* Do a banner in JSON mode*/
+                        if (!DoSubstFromString(DBufValue(&Banner), &buf,
+                                               DSEToday, NO_TIME) &&
+                            DBufLen(&buf)) {
+                            if (JSONLinesEmitted) {
+                                printf("},\n");
+                            }
+                            JSONLinesEmitted++;
+                            printf("{\"banner\":\"");
+                            remove_trailing_newlines(&buf);
+                            PrintJSONString(DBufValue(&buf));
+                            printf("\"");
+                        }
+                        DBufFree(&buf);
+                    }
+                    if (JSONLinesEmitted) {
+                        printf("},\n");
+                    }
+                    printf("{\"noreminders\":\"");
+                    PrintJSONString(GetErr(E_NOREMINDERS));
+                    printf("\"");
+                    JSONLinesEmitted++;
+                }
             } else if (!Daemon && !NextMode && !NumTriggered) {
                 printf(GetErr(M_QUEUED), NumQueued);
                 printf("\n");
@@ -204,6 +235,12 @@ int main(int argc, char *argv[])
         /* If there are sorted reminders, handle them */
         if (SortByDate) IssueSortedReminders();
 
+        if (JSONMode) {
+            if (JSONLinesEmitted) {
+                printf("}\n");
+            }
+            printf("]\n");
+        }
         /* If there are any background reminders queued up, handle them */
         if (NumQueued || Daemon) {
 
@@ -252,6 +289,7 @@ PerIterationInit(void)
     DefaultColorG = -1;
     DefaultColorB = -1;
     NumTriggered = 0;
+    JSONLinesEmitted = 0;
     ClearLastTriggers();
     ClearDedupeTable();
 }
@@ -333,6 +371,7 @@ static void DoReminders(void)
             case T_Rem:     r=DoRem(&p); purge_handled = 1; break;
             case T_ErrMsg:  r=DoErrMsg(&p);  break;
             case T_If:      r=DoIf(&p);      break;
+            case T_Return:  r=DoReturn(&p);  break;
             case T_IfTrig:  r=DoIfTrig(&p);  break;
             case T_Else:    r=DoElse(&p);    break;
             case T_EndIf:   r=DoEndif(&p);   break;
@@ -1251,7 +1290,7 @@ int DoIfTrig(ParsePtr p)
     } else {
         if ( (r=ParseRem(p, &trig, &tim)) ) return r;
         if (trig.typ != NO_TYPE) return E_PARSE_ERR;
-        dse = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
+        dse = ComputeTrigger(get_scanfrom(&trig), &trig, &tim, &r, 1);
         if (r) {
             if (r != E_CANT_TRIG || !trig.maybe_uncomputable) {
                 if (!Hush || r != E_RUN_DISABLED) {
@@ -1537,6 +1576,15 @@ void DoExit(ParsePtr p)
 
     if (PurgeMode) return;
 
+    if (JSONMode) {
+        if (JSONLinesEmitted) {
+            printf("}\n");
+        }
+        /* Close the reminder list */
+        printf("]\n");
+    }
+    fflush(stdout);
+    fflush(stderr);
     r = EvaluateExpr(p, &v);
     if (r || v.type != INT_TYPE) exit(99);
     exit(v.v.val);
@@ -2017,11 +2065,15 @@ ClearLastTriggers(void)
     LastTrigger.warn[0] = 0;
     LastTrigger.omitfunc[0] = 0;
     LastTrigger.passthru[0] = 0;
+    LastTrigger.is_todo = 0;
+    LastTrigger.complete_through = NO_DATE;
+    LastTrigger.max_overdue = -1;
     FreeTrig(&LastTrigger);
     LastTimeTrig.ttime = NO_TIME;
     LastTimeTrig.delta = NO_DELTA;
     LastTimeTrig.rep   = NO_REP;
     LastTimeTrig.duration = NO_TIME;
+
 }
 
 void
@@ -2098,7 +2150,12 @@ System(char const *cmd, int is_queued)
         }
     }
     /* This is the child process or original if we never forked */
-    (void) system(cmd);
+    if (JSONMode) {
+
+        (void) system_to_stderr(cmd);
+    } else {
+        (void) system(cmd);
+    }
     if (do_exit) {
         /* In the child process, so exit! */
         exit(0);
