@@ -51,7 +51,7 @@ int DoRem (ParsePtr p);
 int DoFlush (ParsePtr p);
 void DoExit (ParsePtr p);
 int ParseRem (ParsePtr s, Trigger *trig, TimeTrig *tim);
-int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is_queued, DynamicBuffer *output);
+int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is_queued, DynamicBuffer *output, int *r, int *g, int *b);
 int ShouldTriggerReminder (Trigger const *t, TimeTrig const *tim, int dse, int *err);
 int DoSubst (ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int dse, int mode);
 int DoSubstFromString (char const *source, DynamicBuffer *dbuf, int dse, int tim);
@@ -66,6 +66,7 @@ void unlimit_execution_time(void);
 expr_node *free_expr_tree(expr_node *node);
 expr_node *clone_expr_tree(expr_node const *node, int *r);
 int EvalExpr (char const **e, Value *v, ParsePtr p);
+int EvalExprRunDisabled(char const **e, Value *v, ParsePtr p);
 int DoCoerce (char type, Value *v);
 char const *PrintValue  (Value *v, FILE *fp);
 int CopyValue (Value *dest, const Value *src);
@@ -103,8 +104,8 @@ int SystemDate (int *y, int *m, int *d);
 int DoIf (ParsePtr p);
 int DoElse (ParsePtr p);
 int DoEndif (ParsePtr p);
+int DoReturn (ParsePtr p);
 int DoIfTrig (ParsePtr p);
-int ShouldIgnoreLine (void);
 int VerifyEoln (ParsePtr p);
 int DoRun (ParsePtr p);
 int DoExpr (ParsePtr p);
@@ -218,7 +219,7 @@ void clear_callstack(void);
 int print_callstack(FILE *fp);
 void pop_call(void);
 void FixSpecialType(Trigger *trig);
-void WriteJSONTrigger(Trigger const *t, int include_tags, int today);
+void WriteJSONTrigger(Trigger const *t, int include_tags);
 void WriteJSONTimeTrigger(TimeTrig const *tt);
 int GetOnceDate(void);
 #ifdef REM_USE_WCHAR
@@ -290,3 +291,7 @@ void pop_excess_ifs(char const *fname);
 
 void SetCurrentFilename(char const *fname);
 char const *GetCurrentFilename(void);
+int get_scanfrom(Trigger const *t);
+void remove_trailing_newlines(DynamicBuffer *buf);
+void set_cloexec(int fd);
+int system_to_stderr(char const *cmd);
