@@ -136,6 +136,8 @@ typedef struct {
     int from;
     int adj_for_last;            /* Adjust month/year for use of LAST */
     int need_wkday;              /* Set if we *need* a weekday */
+    int is_todo;                 /* This is a TODO reminder */
+    int complete_through;        /* DSE of complete-through date */
     int priority;
     int duration_days;           /* Duration converted to days to search */
     int eventstart;              /* Original event start (datetime) */
@@ -143,6 +145,7 @@ typedef struct {
     int maybe_uncomputable;      /* Suppress "can't compute trigger" warnings */
     int addomit;                 /* Add trigger date to global OMITs */
     int noqueue;                 /* Don't queue even if timed */
+    int max_overdue;             /* Stop warning if TODO is too far overdue */
     char sched[VAR_NAME_LEN+1];  /* Scheduling function */
     char warn[VAR_NAME_LEN+1];   /* Warning function    */
     char omitfunc[VAR_NAME_LEN+1]; /* OMITFUNC function */
@@ -194,6 +197,7 @@ typedef Parser *ParsePtr;  /* Pointer to parser structure */
 #define AFTER_SKIP 3
 
 #define NO_TIME INT_MAX
+#define NO_SCANFROM INT_MIN
 
 #define NO_PRIORITY 5000 /* Default priority is midway between 0 and 9999 */
 
@@ -226,16 +230,16 @@ typedef Parser *ParsePtr;  /* Pointer to parser structure */
 /* Enumeration of the tokens */
 enum TokTypes
 { T_Illegal,
-  T_AddOmit, T_At, T_Back, T_BackAdj, T_Banner, T_Clr, T_Comment,
+  T_AddOmit, T_At, T_Back, T_BackAdj, T_Banner, T_Clr, T_Comment, T_CompleteThrough,
   T_Date, T_DateTime, T_Day, T_Debug, T_Delta, T_Dumpvars, T_Duration,
   T_Else, T_Empty, T_EndIf, T_ErrMsg, T_Exit, T_Expr, T_Flush,
   T_Frename, T_Fset, T_Funset, T_If, T_IfTrig, T_In, T_Include,
   T_IncludeCmd, T_IncludeR, T_IncludeSys, T_Info, T_LastBack,
-  T_LongTime, T_MaybeUncomputable, T_Month, T_NoQueue, T_Number,
+  T_LongTime, T_MaxOverdue, T_MaybeUncomputable, T_Month, T_NoQueue, T_Number,
   T_Omit, T_OmitFunc, T_Once, T_Ordinal, T_Pop, T_PopFuncs, T_PopVars,
   T_Preserve, T_Priority, T_Push, T_PushFuncs, T_PushVars, T_Rem,
-  T_RemType, T_Rep, T_Scanfrom, T_Sched, T_Set, T_Skip, T_Tag,
-  T_Through, T_Time, T_Translate, T_UnSet, T_Until, T_Warn, T_WkDay,
+  T_RemType, T_Rep, T_Return, T_Scanfrom, T_Sched, T_Set, T_Skip, T_Tag,
+  T_Through, T_Time, T_Todo, T_Translate, T_UnSet, T_Until, T_Warn, T_WkDay,
   T_Year
 };
 
@@ -259,6 +263,8 @@ typedef struct {
 #define RUN_SCRIPT   0x02
 #define RUN_NOTOWNER 0x04
 #define RUN_IN_EVAL  0x08
+#define RUN_UF       0x10 /* A user-function defined with RUN OFF */
+#define RUN_CB       0x20 /* A callback */
 
 /* Flags for the SimpleCalendar format */
 #define SC_AMPM   0   /* Time shown as 3:00am, etc. */
@@ -313,6 +319,7 @@ typedef struct udf_struct {
     int lineno_start;
     int recurse_flag;
     int been_pushed;
+    int run_disabled;
 } UserFunc;
 
 /* A pushed systtem variable */
